@@ -14,7 +14,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.23.0"
+version = "1.25.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -58,7 +58,8 @@ config_keys = ["aports",
                "ui_extras",
                "user",
                "work",
-               "boot_size"]
+               "boot_size",
+               "extra_space"]
 
 # Config file/commandline default values
 # $WORK gets replaced with the actual value for args.work (which may be
@@ -94,6 +95,7 @@ defaults = {
     "user": "user",
     "work": os.path.expanduser("~") + "/.local/var/pmbootstrap",
     "boot_size": "128",
+    "extra_space": "0"
 }
 
 #
@@ -250,6 +252,7 @@ apkbuild_package_attributes = {
     "pkgdesc": {},
     "depends": {"array": True},
     "provides": {"array": True},
+    "install": {"array": True},
 
     # UI meta-packages can specify apps in "_pmb_recommends" to be explicitly
     # installed by default, and not implicitly as dependency of the UI meta-
@@ -268,6 +271,7 @@ apkbuild_attributes = {
     "makedepends": {"array": True},
     "checkdepends": {"array": True},
     "options": {"array": True},
+    "triggers": {"array": True},
     "pkgname": {},
     "pkgrel": {},
     "pkgver": {},
@@ -283,6 +287,7 @@ apkbuild_attributes = {
     "_device": {},
     "_kernver": {},
     "_outdir": {},
+    "_config": {},
 
     # mesa
     "_llvmver": {},
@@ -325,6 +330,7 @@ deviceinfo_attributes = [
     "screen_height",
     "dev_touchscreen",
     "dev_touchscreen_calibration",
+    "append_dtb",
 
     # bootloader
     "flash_method",
@@ -418,6 +424,7 @@ flash_mount_bind = [
 Flasher abstraction. Allowed variables:
 
 $BOOT: Path to the /boot partition
+$DTB: Set to "-dtb" if deviceinfo_append_dtb is set, otherwise ""
 $FLAVOR: Kernel flavor
 $IMAGE: Path to the combined boot/rootfs image
 $IMAGE_SPLIT_BOOT: Path to the (split) boot image
@@ -481,7 +488,8 @@ flashers = {
                 ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
             "flash_kernel": [["heimdall_flash_kernel.sh",
                               "$BOOT/initramfs-$FLAVOR", "$PARTITION_INITFS",
-                              "$BOOT/vmlinuz-$FLAVOR", "$PARTITION_KERNEL"]]
+                              "$BOOT/vmlinuz-$FLAVOR$DTB",
+                              "$PARTITION_KERNEL"]]
         },
     },
     # Some Samsung devices need a 'boot.img' file, just like the one generated
