@@ -15,6 +15,7 @@ import pmb.chroot.other
 import pmb.config
 import pmb.export
 import pmb.flasher
+import pmb.helpers.devices
 import pmb.helpers.git
 import pmb.helpers.lint
 import pmb.helpers.logging
@@ -367,6 +368,20 @@ def kconfig(args):
         pmb.build.menuconfig(args, args.package)
 
 
+def deviceinfo_parse(args):
+    # Default to all devices
+    devices = args.devices
+    if not devices:
+        devices = pmb.helpers.devices.list_codenames(args)
+
+    # Iterate over all devices
+    kernel = args.deviceinfo_parse_kernel
+    for device in devices:
+        print(f"{device}, with kernel={kernel}:")
+        print(json.dumps(pmb.parse.deviceinfo(args, device, kernel), indent=4,
+                         sort_keys=True))
+
+
 def apkbuild_parse(args):
     # Default to all packages
     packages = args.packages
@@ -451,7 +466,7 @@ def work_migrate(args):
 def log(args):
     if args.clear_log:
         pmb.helpers.run.user(args, ["truncate", "-s", "0", args.log])
-    pmb.helpers.run.user(args, ["tail", "-f", args.log, "-n", args.lines],
+    pmb.helpers.run.user(args, ["tail", "-n", args.lines, "-F", args.log],
                          output="tui")
 
 
@@ -459,7 +474,7 @@ def log_distccd(args):
     logpath = "/home/pmos/distccd.log"
     if args.clear_log:
         pmb.chroot.user(args, ["truncate", "-s", "0", logpath])
-    pmb.chroot.user(args, ["tail", "-f", logpath, "-n", args.lines],
+    pmb.chroot.user(args, ["tail", "-n", args.lines, "-f", logpath],
                     output="tui")
 
 
