@@ -51,7 +51,7 @@ def get_subpartitions_size(args, suffix):
     chroot = f"{args.work}/chroot_{suffix}"
     root = pmb.helpers.other.folder_size(args, chroot) / 1024 / 1024
     root *= 1.20
-    root += 50
+    root += 50 + int(args.extra_space)
     return (boot, root)
 
 
@@ -462,15 +462,15 @@ def sanity_check_ondev_version(args):
                            f" / in the binary packages has version {ver_pkg}.")
 
 
-def install_system_image(args, size_reserve, suffix, root_label="pmOS_root",
-                         step=3, steps=5, split=False, sdcard=None):
+def install_system_image(args, size_reserve, suffix, step, steps,
+                         root_label="pmOS_root", split=False, sdcard=None):
     """
     :param size_reserve: empty partition between root and boot in MiB (pma#463)
     :param suffix: the chroot suffix, where the rootfs that will be installed
                    on the device has been created (e.g. "rootfs_qemu-amd64")
-    :param root_label: label of the root partition (e.g. "pmOS_root")
     :param step: next installation step
     :param steps: total installation steps
+    :param root_label: label of the root partition (e.g. "pmOS_root")
     :param split: create separate images for boot and root partitions
     :param sdcard: path to sdcard device (e.g. /dev/mmcblk0) or None
     """
@@ -514,14 +514,10 @@ def install_system_image(args, size_reserve, suffix, root_label="pmOS_root",
                         working_dir="/home/pmos/rootfs/")
 
 
-def print_flash_info(args, step=5, steps=5):
+def print_flash_info(args):
     """ Print flashing information, based on the deviceinfo data and the
-        pmbootstrap arguments.
-
-        :param step: installation step number """
-    logging.info(f"*** ({step}/{steps}) FLASHING TO DEVICE ***")
-    logging.info("Run the following to flash your installation to the"
-                 " target device:")
+        pmbootstrap arguments. """
+    logging.info("*** FLASHING INFORMATION ***")
 
     # System flash information
     method = args.deviceinfo["flash_method"]
@@ -529,6 +525,16 @@ def print_flash_info(args, step=5, steps=5):
     flasher_actions = flasher.get("actions", {})
     requires_split = flasher.get("split", False)
 
+    if method == "none":
+        logging.info("Refer to the installation instructions of your device,"
+                     " or the generic install instructions in the wiki.")
+        logging.info("https://wiki.postmarketos.org/wiki/Installation_guide"
+                     "#pmbootstrap_flash")
+        return
+
+    logging.info("Run the following to flash your installation to the"
+                 " target device:")
+
     if "flash_rootfs" in flasher_actions and not args.sdcard and \
             bool(args.split) == requires_split:
         logging.info("* pmbootstrap flasher flash_rootfs")
@@ -577,16 +583,16 @@ def print_flash_info(args, step=5, steps=5):
                  " and flash outside of pmbootstrap.")
 
 
-def install_recovery_zip(args):
-    logging.info("*** (3/4) CREATING RECOVERY-FLASHABLE ZIP ***")
+def install_recovery_zip(args, steps):
+    logging.info(f"*** ({steps}/{steps}) CREATING RECOVERY-FLASHABLE ZIP ***")
     suffix = "buildroot_" + args.deviceinfo["arch"]
     mount_device_rootfs(args, f"rootfs_{args.device}", suffix)
     pmb.install.recovery.create_zip(args, suffix)
 
     # Flash information
-    logging.info("*** (4/4) FLASHING TO DEVICE ***")
+    logging.info("*** FLASHING INFORMATION ***")
     logging.info("Flashing with the recovery zip is explained here:")
-    logging.info("<https://postmarketos.org/recoveryzip>")
+    logging.info("https://postmarketos.org/recoveryzip")
 
 
 def install_on_device_installer(args, step, steps):
@@ -639,8 +645,8 @@ def install_on_device_installer(args, step, steps):
 
     # Generate installer image
     size_reserve = round(os.path.getsize(img_path_dest) / 1024 / 1024) + 200
-    install_system_image(args, size_reserve, suffix_installer, "pmOS_install",
-                         step, steps, args.split, args.sdcard)
+    install_system_image(args, size_reserve, suffix_installer, step, steps,
+                         "pmOS_install", args.split, args.sdcard)
 
 
 def install(args):
@@ -655,21 +661,24 @@ def install(args):
     if args.no_image:
         steps = 2
     elif args.android_recovery_zip:
-        steps = 4
+        steps = 3
     elif args.on_device_installer:
-        steps = 8
+        steps = 7
     else:
-        steps = 5
+        steps = 4
 
     # Install required programs in native chroot
-    logging.info("*** (1/{}) PREPARE NATIVE CHROOT ***".format(steps))
+    logging.info(f"*** (1/{steps}) PREPARE NATIVE CHROOT ***")
     pmb.chroot.apk.install(args, pmb.config.install_native_packages,
                            build=False)
 
-    # List all packages to be installed (including the ones specified by --add)
-    # and upgrade the installed packages/apkindexes
-    logging.info('*** (2/{0}) CREATE DEVICE ROOTFS ("{1}") ***'.format(steps,
-                                                                       args.device))
+    logging.info(f'*** (2/{steps}) CREATE DEVICE ROOTFS ("{args.device}") ***')
+
+    # Create user before installing packages, so post-install scripts of
+    # pmaports can figure out the username (legacy reasons: pmaports#820)
+    set_user(args)
+
+    # Fill install_packages
     install_packages = (pmb.config.install_device_packages +
                         ["device-" + args.device] +
                         get_kernel_package(args, args.device) +
@@ -681,18 +690,15 @@ def install(args):
         install_packages += ["postmarketos-ui-" + args.ui]
         if args.ui_extras:
             install_packages += ["postmarketos-ui-" + args.ui + "-extras"]
-    suffix = "rootfs_" + args.device
-    pmb.chroot.apk.upgrade(args, suffix)
-
-    # Create final user and remove 'build' user
-    set_user(args)
-
-    # Explicitly call build on the install packages, to re-build them or any
-    # dependency, in case the version increased
     if args.extra_packages.lower() != "none":
         install_packages += args.extra_packages.split(",")
     if args.add:
         install_packages += args.add.split(",")
+
+    pmb.helpers.repo.update(args, args.deviceinfo["arch"])
+
+    # Explicitly call build on the install packages, to re-build them or any
+    # dependency, in case the version increased
     if args.build_pkgs_on_install:
         for pkgname in install_packages:
             pmb.build.package(args, pkgname, args.deviceinfo["arch"])
@@ -700,6 +706,7 @@ def install(args):
     # Install all packages to device rootfs chroot (and rebuild the initramfs,
     # because that doesn't always happen automatically yet, e.g. when the user
     # installed a hook without pmbootstrap - see #69 for more info)
+    suffix = "rootfs_" + args.device
     pmb.chroot.apk.install(args, install_packages, suffix)
     pmb.install.file.write_os_release(args, suffix)
     for flavor in pmb.chroot.other.kernel_flavors_installed(args, suffix):
@@ -720,12 +727,12 @@ def install(args):
     if args.no_image:
         return
     elif args.android_recovery_zip:
-        return install_recovery_zip(args)
+        return install_recovery_zip(args, steps)
 
     if args.on_device_installer:
         # Runs install_system_image twice
         install_on_device_installer(args, 3, steps)
     else:
-        install_system_image(args, 0, f"rootfs_{args.device}",
+        install_system_image(args, 0, f"rootfs_{args.device}", 3, steps,
                              split=args.split, sdcard=args.sdcard)
-    print_flash_info(args, steps, steps)
+    print_flash_info(args)
