@@ -357,6 +357,10 @@ def arguments():
                              pmb.config.defaults["mirror_alpine"],
                         metavar="URL")
     parser.add_argument("-j", "--jobs", help="parallel jobs when compiling")
+    parser.add_argument("-E", "--extra-space",
+                        help="specify an integer with the amount of additional"
+                             "space to allocate to the image in MB (default"
+                             " 0)")
     parser.add_argument("-B", "--boot-size",
                         help="specify an integer with your preferred boot"
                              "partition size on target machine in MB (default"
@@ -623,6 +627,15 @@ def arguments():
                        " a kernel compiled with envkernel.sh.")
     add_packages_arg(build, nargs="+")
 
+    # Action: deviceinfo_parse
+    deviceinfo_parse = sub.add_parser("deviceinfo_parse")
+    deviceinfo_parse.add_argument("devices", nargs="*")
+    deviceinfo_parse.add_argument("--kernel", help="the kernel to select (for"
+                                  " device packages with multiple kernels),"
+                                  " e.g. 'downstream', 'mainline'",
+                                  dest="deviceinfo_parse_kernel",
+                                  metavar="KERNEL")
+
     # Action: apkbuild_parse
     apkbuild_parse = sub.add_parser("apkbuild_parse")
     add_packages_arg(apkbuild_parse, nargs="*")
